@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,14 +20,12 @@
 #pragma once
 
 #include <adwaita.h>
-#include <algorithm>
-#include <ranges>
-#include <string>
-#include <unordered_map>
-#include "app_info.hpp"
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkicontheme.h>
 #include "application.hpp"
 #include "pipeline_type.hpp"
-#include "tags_plugin_name.hpp"
 
 namespace ui::apps_box {
 
