@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,6 +20,13 @@
 #pragma once
 
 #include <ebur128.h>
+#include <sigc++/signal.h>
+#include <sys/types.h>
+#include <span>
+#include <string>
+#include <thread>
+#include <vector>
+#include "pipe_manager.hpp"
 #include "plugin_base.hpp"
 
 class AutoGain : public PluginBase {
