@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects
  *
@@ -19,12 +19,16 @@
 
 #pragma once
 
+#include <sys/types.h>
 #include <zita-convolver.h>
-#include <algorithm>
 #include <deque>
-#include <sndfile.hh>
+#include <span>
+#include <string>
+#include <thread>
+#include <vector>
+#include "pipe_manager.hpp"
 #include "plugin_base.hpp"
-#include "resampler.hpp"
+#include "util.hpp"
 
 class Convolver : public PluginBase {
  public:
