@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,10 +20,12 @@
 #pragma once
 
 #include <adwaita.h>
-#include <filesystem>
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtkpopover.h>
 #include <sndfile.hh>
+#include <string>
 #include "application.hpp"
-#include "ui_helpers.hpp"
 
 namespace ui::convolver_menu_impulses {
 
