@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,11 +19,12 @@
 
 #pragma once
 
+#include <sys/types.h>
 #include <zita-convolver.h>
 #include <algorithm>
-#include <numbers>
-#include <ranges>
 #include <span>
+#include <string>
+#include <vector>
 #include "util.hpp"
 
 class FirFilterBase {
