@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,23 +19,23 @@
 
 #pragma once
 
-#include <dlfcn.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
 #include <lilv/lilv.h>
-#include <lv2/atom/atom.h>
 #include <lv2/buf-size/buf-size.h>
 #include <lv2/core/lv2.h>
-#include <lv2/data-access/data-access.h>
-#include <lv2/instance-access/instance-access.h>
-#include <lv2/lv2plug.in/ns/ext/log/log.h>
-#include <lv2/lv2plug.in/ns/ext/urid/urid.h>
-#include <lv2/options/options.h>
-#include <lv2/parameters/parameters.h>
 #include <lv2/ui/ui.h>
+#include <lv2/urid/urid.h>
+#include <sys/types.h>
 #include <array>
+#include <functional>
+#include <limits>
 #include <mutex>
 #include <span>
-#include <thread>
+#include <string>
 #include <unordered_map>
+#include <vector>
 #include "string_literal_wrapper.hpp"
 #include "util.hpp"
 
@@ -142,9 +142,11 @@ class Lv2Wrapper {
                      }),
                      this);
 
-    gsettings_sync_funcs.emplace_back([=, this]() {
-      g_settings_set_boolean(settings, gkey_wrapper.msg.data(),
-                             static_cast<gboolean>(get_control_port_value(key_wrapper.msg.data())));
+    auto gkey = gkey_wrapper.msg.data();
+    auto key = key_wrapper.msg.data();
+
+    gsettings_sync_funcs.emplace_back([settings, gkey, key, this]() {
+      g_settings_set_boolean(settings, gkey, static_cast<gboolean>(get_control_port_value(key)));
     });
   }
 
@@ -162,9 +164,11 @@ class Lv2Wrapper {
                      }),
                      this);
 
-    gsettings_sync_funcs.emplace_back([=, this]() {
-      g_settings_set_enum(settings, gkey_wrapper.msg.data(),
-                          static_cast<gint>(get_control_port_value(key_wrapper.msg.data())));
+    auto gkey = gkey_wrapper.msg.data();
+    auto key = key_wrapper.msg.data();
+
+    gsettings_sync_funcs.emplace_back([settings, gkey, key, this]() {
+      g_settings_set_enum(settings, gkey, static_cast<gint>(get_control_port_value(key)));
     });
   }
 
@@ -182,9 +186,11 @@ class Lv2Wrapper {
                      }),
                      this);
 
-    gsettings_sync_funcs.emplace_back([=, this]() {
-      g_settings_set_int(settings, gkey_wrapper.msg.data(),
-                         static_cast<gint>(get_control_port_value(key_wrapper.msg.data())));
+    auto gkey = gkey_wrapper.msg.data();
+    auto key = key_wrapper.msg.data();
+
+    gsettings_sync_funcs.emplace_back([settings, gkey, key, this]() {
+      g_settings_set_int(settings, gkey, static_cast<gint>(get_control_port_value(key)));
     });
   }
 
@@ -202,9 +208,11 @@ class Lv2Wrapper {
                      }),
                      this);
 
-    gsettings_sync_funcs.emplace_back([=, this]() {
-      g_settings_set_double(settings, gkey_wrapper.msg.data(),
-                            static_cast<gdouble>(get_control_port_value(key_wrapper.msg.data())));
+    auto gkey = gkey_wrapper.msg.data();
+    auto key = key_wrapper.msg.data();
+
+    gsettings_sync_funcs.emplace_back([settings, gkey, key, this]() {
+      g_settings_set_double(settings, gkey, static_cast<gdouble>(get_control_port_value(key)));
     });
   }
 
@@ -231,12 +239,15 @@ class Lv2Wrapper {
                      }),
                      this);
 
-    gsettings_sync_funcs.emplace_back([=, this]() {
-      const auto linear_v = get_control_port_value(key_wrapper.msg.data());
+    auto gkey = gkey_wrapper.msg.data();
+    auto key = key_wrapper.msg.data();
+
+    gsettings_sync_funcs.emplace_back([settings, gkey, key, this]() {
+      const auto linear_v = get_control_port_value(key);
 
       const auto db_v = (!lower_bound & (linear_v == 0.0F)) ? util::minimum_db_d_level : util::linear_to_db(linear_v);
 
-      g_settings_set_double(settings, gkey_wrapper.msg.data(), static_cast<gdouble>(db_v));
+      g_settings_set_double(settings, gkey, static_cast<gdouble>(db_v));
     });
   }
 
