@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,6 +19,11 @@
 
 #pragma once
 
+#include <sigc++/signal.h>
+#include <sys/types.h>
+#include <span>
+#include <string>
+#include "pipe_manager.hpp"
 #include "plugin_base.hpp"
 
 class Maximizer : public PluginBase {
