@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,6 +19,19 @@
 
 #pragma once
 
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <pipewire/proxy.h>
+#include <sigc++/signal.h>
+#include <sys/types.h>
+#include <array>
+#include <cstddef>
+#include <span>
+#include <string>
+#include <utility>
+#include <vector>
+#include "pipe_manager.hpp"
 #include "plugin_base.hpp"
 #include "tags_multiband_gate.hpp"
 
