@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,14 +20,10 @@
 #pragma once
 
 #include <adwaita.h>
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtkbox.h>
 #include "application.hpp"
-#include "client_info_holder.hpp"
-#include "module_info_holder.hpp"
-#include "node_info_holder.hpp"
-#include "presets_autoloading_holder.hpp"
-#include "tags_resources.hpp"
-#include "test_signals.hpp"
-#include "ui_helpers.hpp"
 
 namespace ui::pipe_manager_box {
 
