@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,8 +19,13 @@
 
 #pragma once
 
+#include <STTypes.h>
 #include <deque>
+#include <span>
+#include <string>
+#include <vector>
 #include "SoundTouch.h"
+#include "pipe_manager.hpp"
 #include "plugin_base.hpp"
 
 class Pitch : public PluginBase {
