@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,14 +19,21 @@
 
 #pragma once
 
+#include <gio/gio.h>
+#include <glib.h>
 #include <pipewire/filter.h>
-#include <spa/param/latency-utils.h>
+#include <sigc++/signal.h>
+#include <spa/utils/hook.h>
+#include <sys/types.h>
+#include <chrono>
+#include <memory>
 #include <mutex>
-#include <ranges>
 #include <span>
+#include <string>
+#include <vector>
 #include "lv2_wrapper.hpp"
 #include "pipe_manager.hpp"
-#include "tags_plugin_name.hpp"
+#include "util.hpp"
 
 class PluginBase {
  public:
