@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,8 +19,9 @@
 
 #pragma once
 
-#include "preferences_general.hpp"
-#include "preferences_spectrum.hpp"
+#include <adwaita.h>
+#include <glib-object.h>
+#include <glibconfig.h>
 
 namespace ui::preferences::window {
 
