@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,6 +19,16 @@
 
 #pragma once
 
+#include <sigc++/signal.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <climits>
+#include <cstddef>
+#include <memory>
+#include <span>
+#include <string>
+#include <vector>
+#include "pipe_manager.hpp"
 #ifdef ENABLE_RNNOISE
 #include <rnnoise.h>
 #endif
