@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,6 +20,8 @@
 #pragma once
 
 #include "effects_base.hpp"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
 
 class StreamOutputEffects : public EffectsBase {
  public:
