@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,12 +19,11 @@
 
 #pragma once
 
-#include <glib/gi18n.h>
+#include <sys/types.h>
 #include <array>
-#include <iostream>
 #include <map>
-#include <regex>
-#include "util.hpp"
+#include <string>
+#include <string_view>
 
 namespace tags::plugin_package {
 
