@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,41 @@
  */
 
 #include "app_info.hpp"
+#include <STTypes.h>
+#define FMT_HEADER_ONLY
+#include <fmt/core.h>
+#include <fmt/format.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gobject/gobject.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkicontheme.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtktogglebutton.h>
+#include <pipewire/node.h>
+#include <algorithm>
+#include <array>
+#include <cctype>
+#include <cmath>
+#include <filesystem>
+#include <string>
+#include <string_view>
+#include <unordered_map>
+#include <utility>
+#include "application.hpp"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
+#include "tags_app.hpp"
+#include "tags_pipewire.hpp"
+#include "tags_resources.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::app_info {
 
@@ -85,8 +120,10 @@ auto app_is_blocklisted(AppInfo* self, const std::string& name) -> bool {
 auto get_app_icon_name(const NodeInfo& node_info) -> std::string {
   // map to handle cases where PipeWire does not set icon name string or app name equal to icon name.
 
-  constexpr auto icon_map = std::to_array<std::pair<const char*, const char*>>(
-      {{"chromium-browser", "chromium"}, {"firefox", "firefox"}, {"nightly","firefox-nightly"}, {"obs", "com.obsproject.Studio"}});
+  constexpr auto icon_map = std::to_array<std::pair<const char*, const char*>>({{"chromium-browser", "chromium"},
+                                                                                {"firefox", "firefox"},
+                                                                                {"nightly", "firefox-nightly"},
+                                                                                {"obs", "com.obsproject.Studio"}});
 
   std::string icon_name;
 
@@ -225,7 +262,28 @@ void update(AppInfo* self, const NodeInfo node_info) {
 
   self->data->info = node_info;
 
-  gtk_label_set_text(self->app_name, node_info.name.c_str());
+  std::string app_name = node_info.app_name;
+
+  auto isspace = [](std::string_view a) { return std::ranges::all_of(a, [](auto c) { return std::isspace(c); }); };
+
+  if (app_name.empty() || isspace(app_name)) {
+    app_name = node_info.name;
+  }
+
+  if (app_name.empty() || isspace(app_name)) {
+    app_name = node_info.app_process_binary;
+  }
+
+  if (app_name.empty() || isspace(app_name)) {
+    app_name = node_info.app_process_binary;
+  }
+
+  if (app_name.empty()) {
+    app_name = _("Undefined Name - Process ID ");
+    app_name.append(node_info.app_process_id);
+  }
+
+  gtk_label_set_text(self->app_name, app_name.c_str());
   gtk_label_set_text(self->media_name, node_info.media_name.c_str());
   gtk_label_set_text(self->format, node_info.format.c_str());
   gtk_label_set_text(
