@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,8 +18,34 @@
  */
 
 #include "application.hpp"
+#include <adwaita.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <spa/param/param.h>
+#include <spa/utils/defs.h>
+#include <array>
+#include <cstdlib>
+#include <iostream>
+#include <ostream>
+#include <string>
+#include <thread>
 #include "application_ui.hpp"
 #include "config.h"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
+#include "preferences_window.hpp"
+#include "preset_type.hpp"
+#include "presets_manager.hpp"
+#include "stream_input_effects.hpp"
+#include "stream_output_effects.hpp"
+#include "tags_app.hpp"
+#include "tags_pipewire.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "util.hpp"
 
 namespace app {
 
@@ -95,7 +121,7 @@ void on_startup(GApplication* gapp) {
       return;
     }
 
-    util::debug("device "s + device.name + " has changed its input route to: "s + device.input_route_name);
+    util::debug("device " + device.name + " has changed its input route to: " + device.input_route_name);
 
     NodeInfo target_node;
 
@@ -127,7 +153,7 @@ void on_startup(GApplication* gapp) {
       return;
     }
 
-    util::debug("device "s + device.name + " has changed its output route to: "s + device.output_route_name);
+    util::debug("device " + device.name + " has changed its output route to: " + device.output_route_name);
 
     NodeInfo target_node;
 
@@ -260,7 +286,7 @@ void application_class_init(ApplicationClass* klass) {
         list += name + ",";
       }
 
-      std::cout << _("Output Presets") + ": "s + list << std::endl;
+      std::cout << _("Output Presets") + ": "s + list << '\n';
 
       list = "";
 
@@ -268,7 +294,7 @@ void application_class_init(ApplicationClass* klass) {
         list += name + ",";
       }
 
-      std::cout << _("Input Presets") + ": "s + list << std::endl;
+      std::cout << _("Input Presets") + ": "s + list << '\n';
 
       return EXIT_SUCCESS;
     }
@@ -276,7 +302,7 @@ void application_class_init(ApplicationClass* klass) {
     if (g_variant_dict_contains(options, "bypass") != 0) {
       if (int bypass_arg = 2; g_variant_dict_lookup(options, "bypass", "i", &bypass_arg)) {
         if (bypass_arg == 3) {
-          std::cout << g_settings_get_boolean(self->settings, "bypass") << std::endl;
+          std::cout << g_settings_get_boolean(self->settings, "bypass") << '\n';
 
           return EXIT_SUCCESS;
         }
@@ -290,7 +316,7 @@ void application_class_init(ApplicationClass* klass) {
 
   application_class->command_line = [](GApplication* gapp, GApplicationCommandLine* cmdline) {
     auto* self = EE_APP(gapp);
-    auto* options = g_application_command_line_get_options_dict(cmdline);
+    GVariantDict* options = g_application_command_line_get_options_dict(cmdline);
 
     if (g_variant_dict_contains(options, "quit") != 0) {
       hide_all_windows(gapp);
@@ -300,6 +326,12 @@ void application_class_init(ApplicationClass* klass) {
       return EXIT_SUCCESS;
     }
 
+    if (g_variant_dict_contains(options, "version") != 0) {
+      std::cout << "easyeffects version: " << std::string(VERSION) << '\n';
+
+      return EXIT_SUCCESS;
+    }
+
     if (g_variant_dict_contains(options, "load-preset") != 0) {
       const char* name = nullptr;
 
@@ -432,6 +464,20 @@ void application_init(Application* self) {
 
   entries[1] = {"help",
                 [](GSimpleAction* action, GVariant* parameter, gpointer gapp) {
+                  /*
+                    It isn't secure to call std::system but it is the only way to make our help to be shown for KDE
+                    users.
+                  */
+
+                  if (g_strcmp0(std::getenv("XDG_SESSION_DESKTOP"), "KDE") == 0 ||
+                      g_strcmp0(std::getenv("XDG_CURRENT_DESKTOP"), "KDE") == 0) {
+                    std::thread t([]() { return std::system("yelp help:easyeffects"); });
+
+                    t.detach();
+
+                    return;
+                  }
+
                   auto* parent = gtk_application_get_active_window(GTK_APPLICATION(gapp));
 
                   auto* launcher = gtk_uri_launcher_new("help:easyeffects");
@@ -549,8 +595,8 @@ auto application_new() -> GApplication* {
   g_application_add_main_option(G_APPLICATION(app), "quit", 'q', G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE,
                                 _("Quit Easy Effects. Useful when running in service mode."), nullptr);
 
-  g_application_add_main_option(G_APPLICATION(app), "load-preset", 'l', G_OPTION_FLAG_NONE, G_OPTION_ARG_STRING,
-                                _("Load a preset. Example: easyeffects -l music"), nullptr);
+  g_application_add_main_option(G_APPLICATION(app), "version", 'v', G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE,
+                                _("Print the easyeffects version"), nullptr);
 
   g_application_add_main_option(G_APPLICATION(app), "reset", 'r', G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE,
                                 _("Reset Easy Effects."), nullptr);
@@ -564,6 +610,9 @@ auto application_new() -> GApplication* {
   g_application_add_main_option(G_APPLICATION(app), "presets", 'p', G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE,
                                 _("Show available presets."), nullptr);
 
+  g_application_add_main_option(G_APPLICATION(app), "load-preset", 'l', G_OPTION_FLAG_NONE, G_OPTION_ARG_STRING,
+                                _("Load a preset. Example: easyeffects -l music"), nullptr);
+
   return G_APPLICATION(app);
 }
 
