@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,27 @@
  */
 
 #include "chart.hpp"
+#include <cairo.h>
+#include <fmt/format.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <gobject/gobject.h>
+#include <graphene.h>
+#include <gsk/gsk.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkshortcut.h>
+#include <pango/pango-font.h>
+#include <pango/pango-layout.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <array>
+#include <cmath>
+#include <cstddef>
+#include <string>
+#include <vector>
+#include "tags_resources.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::chart {
 
@@ -174,7 +195,7 @@ void set_margin(Chart* self, const float& v) {
 }
 
 auto get_is_visible(Chart* self) -> bool {
-  if (self == nullptr) {
+  if (!GTK_IS_WIDGET(self)) {
     return false;
   }
 
@@ -196,7 +217,7 @@ void set_dynamic_y_scale(Chart* self, const bool& v) {
 }
 
 void set_x_data(Chart* self, const std::vector<double>& x) {
-  if (self == nullptr || x.empty()) {
+  if (!GTK_IS_WIDGET(self) || x.empty()) {
     return;
   }
 
@@ -231,7 +252,7 @@ void set_x_data(Chart* self, const std::vector<double>& x) {
 }
 
 void set_y_data(Chart* self, const std::vector<double>& y) {
-  if (self == nullptr || y.empty()) {
+  if (!GTK_IS_WIDGET(self) || y.empty()) {
     return;
   }
 
@@ -359,7 +380,7 @@ auto draw_x_labels(Chart* self, GtkSnapshot* snapshot, const int& width, const i
     }
   }
 
-  draw_unit(self, snapshot, width, height, " "s + self->data->x_unit + " "s);
+  draw_unit(self, snapshot, width, height, " " + self->data->x_unit + " ");
 
   /*
     There is no space left in the window to show the last label. So we skip it.
