@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,28 @@
  */
 
 #include "convolver_menu_combine.hpp"
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkdropdown.h>
+#include <sndfile.h>
+#include <algorithm>
+#include <cstddef>
+#include <execution>
+#include <filesystem>
+#include <memory>
+#include <numeric>
+#include <sndfile.hh>
+#include <string>
+#include <thread>
+#include <vector>
+#include "convolver_ui_common.hpp"
+#include "resampler.hpp"
+#include "tags_app.hpp"
+#include "tags_resources.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::convolver_menu_combine {
 
@@ -96,7 +118,9 @@ void combine_kernels(ConvolverMenuCombine* self,
   if (output_file_name.empty()) {
     // The method combine_kernels run in a secondary thread. But the widgets have to be used in the main thread.
 
-    util::idle_add([=] { gtk_spinner_stop(self->spinner); });
+    g_object_ref(self);
+
+    util::idle_add([=] { gtk_spinner_stop(self->spinner); }, [=]() { g_object_unref(self); });
 
     return;
   }
@@ -105,7 +129,9 @@ void combine_kernels(ConvolverMenuCombine* self,
   auto [rate2, kernel_2_L, kernel_2_R] = ui::convolver::read_kernel(irs_dir, irs_ext, kernel_2_name);
 
   if (rate1 == 0 || rate2 == 0) {
-    util::idle_add([=] { gtk_spinner_stop(self->spinner); });
+    g_object_ref(self);
+
+    util::idle_add([=] { gtk_spinner_stop(self->spinner); }, [=]() { g_object_unref(self); });
 
     return;
   }
@@ -165,7 +191,9 @@ void combine_kernels(ConvolverMenuCombine* self,
 
   util::debug("combined kernel saved: " + output_file_path.string());
 
-  util::idle_add([=] { gtk_spinner_stop(self->spinner); });
+  g_object_ref(self);
+
+  util::idle_add([=] { gtk_spinner_stop(self->spinner); }, [=]() { g_object_unref(self); });
 }
 
 void on_combine_kernels(ConvolverMenuCombine* self, GtkButton* btn) {
