@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,40 @@
  */
 
 #include "convolver_ui.hpp"
+#include <STTypes.h>
+#include <fftw3.h>
+#include <fmt/format.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <glibconfig.h>
+#include <gobject/gobject.h>
+#include <gsl/gsl_interp.h>
+#include <gsl/gsl_spline.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkshortcut.h>
+#include <sigc++/connection.h>
+#include <algorithm>
+#include <cmath>
+#include <cstddef>
+#include <filesystem>
+#include <memory>
+#include <mutex>
+#include <numbers>
+#include <string>
+#include <thread>
+#include <vector>
+#include "application.hpp"
+#include "chart.hpp"
+#include "convolver.hpp"
+#include "convolver_menu_combine.hpp"
+#include "convolver_menu_impulses.hpp"
+#include "convolver_ui_common.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::convolver_box {
 
@@ -303,19 +337,23 @@ void get_irs_spectrum(ConvolverBox* self, const int& rate) {
     self->data->right_spectrum[n] = (self->data->right_spectrum[n] - fft_min_right) / (fft_max_right - fft_min_right);
   }
 
-  util::idle_add([=]() {
-    if (self == nullptr) {
-      return;
-    }
+  g_object_ref(self);
 
-    if (!ui::chart::get_is_visible(self->chart)) {
-      return;
-    }
+  util::idle_add(
+      [=]() {
+        if (self == nullptr) {
+          return;
+        }
 
-    if (gtk_toggle_button_get_active(self->show_fft) != 0) {
-      plot_fft(self);
-    }
-  });
+        if (!ui::chart::get_is_visible(self->chart)) {
+          return;
+        }
+
+        if (gtk_toggle_button_get_active(self->show_fft) != 0) {
+          plot_fft(self);
+        }
+      },
+      [=]() { g_object_unref(self); });
 }
 
 void get_irs_info(ConvolverBox* self) {
@@ -510,8 +548,6 @@ void setup(ConvolverBox* self,
 void dispose(GObject* object) {
   auto* self = EE_CONVOLVER_BOX(object);
 
-  self->data->convolver->set_post_messages(false);
-
   set_ignore_filter_idle_add(self->data->serial, true);
 
   g_file_monitor_cancel(self->folder_monitor);
