@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,22 @@
  */
 
 #include "crystalizer.hpp"
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <cstddef>
+#include <memory>
+#include <mutex>
+#include <span>
+#include <string>
+#include "fir_filter_bandpass.hpp"
+#include "fir_filter_base.hpp"
+#include "pipe_manager.hpp"
+#include "plugin_base.hpp"
+#include "tags_plugin_name.hpp"
+#include "util.hpp"
 
 Crystalizer::Crystalizer(const std::string& tag,
                          const std::string& schema,
@@ -227,7 +243,7 @@ void Crystalizer::process(std::span<float>& left_in,
 
     util::debug(log_tag + name + " latency: " + util::to_string(latency_value, "") + " s");
 
-    util::idle_add([=, this]() {
+    util::idle_add([this]() {
       if (!post_messages || latency.empty()) {
         return;
       }
