@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,15 @@
  */
 
 #include "deesser.hpp"
+#include <algorithm>
+#include <memory>
+#include <span>
+#include <string>
+#include "lv2_wrapper.hpp"
+#include "pipe_manager.hpp"
+#include "plugin_base.hpp"
+#include "tags_plugin_name.hpp"
+#include "util.hpp"
 
 Deesser::Deesser(const std::string& tag,
                  const std::string& schema,
