@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,35 @@
  */
 
 #include "effects_box.hpp"
+#include <STTypes.h>
+#include <adwaita.h>
+#include <fmt/core.h>
+#include <fmt/format.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gobject/gobject.h>
+#include <gsl/gsl_interp.h>
+#include <gsl/gsl_spline.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkshortcut.h>
+#include <sigc++/connection.h>
+#include <algorithm>
+#include <cstddef>
+#include <vector>
+#include "application.hpp"
+#include "apps_box.hpp"
+#include "blocklist_menu.hpp"
+#include "chart.hpp"
+#include "effects_base.hpp"
+#include "pipeline_type.hpp"
+#include "plugins_box.hpp"
+#include "tags_app.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace {
 
@@ -226,21 +255,27 @@ void setup_spectrum(EffectsBox* self) {
 
   self->data->gconnections_spectrum.push_back(g_signal_connect(
       self->settings_spectrum, "changed::n-points", G_CALLBACK(+[](GSettings* settings, char* key, EffectsBox* self) {
-        util::idle_add([=]() { init_spectrum_frequency_axis(self); });
+        g_object_ref(self);
+
+        util::idle_add([=]() { init_spectrum_frequency_axis(self); }, [=]() { g_object_unref(self); });
       }),
       self));
 
   self->data->gconnections_spectrum.push_back(
       g_signal_connect(self->settings_spectrum, "changed::minimum-frequency",
                        G_CALLBACK(+[](GSettings* settings, char* key, EffectsBox* self) {
-                         util::idle_add([=]() { init_spectrum_frequency_axis(self); });
+                         g_object_ref(self);
+
+                         util::idle_add([=]() { init_spectrum_frequency_axis(self); }, [=]() { g_object_unref(self); });
                        }),
                        self));
 
   self->data->gconnections_spectrum.push_back(
       g_signal_connect(self->settings_spectrum, "changed::maximum-frequency",
                        G_CALLBACK(+[](GSettings* settings, char* key, EffectsBox* self) {
-                         util::idle_add([=]() { init_spectrum_frequency_axis(self); });
+                         g_object_ref(self);
+
+                         util::idle_add([=]() { init_spectrum_frequency_axis(self); }, [=]() { g_object_unref(self); });
                        }),
                        self));
 }
@@ -462,8 +497,6 @@ void dispose(GObject* object) {
 
   self->data->effects_base->spectrum->bypass = true;
 
-  self->data->effects_base->output_level->set_post_messages(false);
-
   for (auto& c : self->data->connections) {
     c.disconnect();
   }
