@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,23 @@
  */
 
 #include "equalizer.hpp"
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <map>
+#include <memory>
+#include <span>
+#include <string>
+#include <utility>
+#include <vector>
+#include "lv2_wrapper.hpp"
+#include "pipe_manager.hpp"
+#include "plugin_base.hpp"
+#include "tags_equalizer.hpp"
+#include "tags_plugin_name.hpp"
+#include "util.hpp"
 
 using namespace std::string_literals;
 
@@ -249,7 +266,7 @@ void Equalizer::process(std::span<float>& left_in,
 
     util::debug(log_tag + name + " latency: " + util::to_string(latency_value, "") + " s");
 
-    util::idle_add([=, this]() {
+    util::idle_add([this]() {
       if (!post_messages || latency.empty()) {
         return;
       }
