@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,17 @@
  */
 
 #include "fir_filter_base.hpp"
+#include <sched.h>
+#include <sys/types.h>
+#include <zita-convolver.h>
+#include <algorithm>
+#include <cmath>
+#include <cstddef>
+#include <numbers>
+#include <string>
+#include <utility>
+#include <vector>
+#include "util.hpp"
 
 namespace {
 
