@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,20 @@
  */
 
 #include "ladspa_wrapper.hpp"
+#include <dlfcn.h>
+#include <ladspa.h>
+#include <sys/types.h>
+#include <cassert>
+#include <cmath>
+#include <cstdlib>
+#include <cstring>
+#include <limits>
+#include <span>
+#include <string>
+#include <tuple>
+#include <utility>
+#include "config.h"
+#include "util.hpp"
 
 namespace ladspa {
 
