@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,32 @@
  */
 
 #include "lv2_wrapper.hpp"
+#include <dlfcn.h>
+#include <lilv/lilv.h>
+#include <lv2/atom/atom.h>
+#include <lv2/buf-size/buf-size.h>
+#include <lv2/core/lv2.h>
+#include <lv2/data-access/data-access.h>
+#include <lv2/instance-access/instance-access.h>
+#include <lv2/lv2plug.in/ns/ext/log/log.h>
+#include <lv2/options/options.h>
+#include <lv2/parameters/parameters.h>
+#include <lv2/ui/ui.h>
+#include <lv2/urid/urid.h>
+#include <sys/types.h>
+#include <array>
+#include <chrono>
+#include <cmath>
+#include <cstdarg>
+#include <cstdint>
+#include <cstdio>
+#include <functional>
+#include <mutex>
+#include <span>
+#include <string>
+#include <thread>
+#include <vector>
+#include "util.hpp"
 
 namespace lv2 {
 
@@ -428,7 +454,7 @@ auto Lv2Wrapper::map_urid(const std::string& uri) -> LV2_URID {
 void Lv2Wrapper::load_ui() {
   // preparing the thread that loads the native ui and updates it over time
 
-  std::thread ui_updater([=, this]() {
+  std::thread ui_updater([this]() {
     {
       std::scoped_lock<std::mutex> lku(ui_mutex);
 
@@ -454,7 +480,7 @@ void Lv2Wrapper::load_ui() {
 
         std::string ui_uri = lilv_node_as_uri(lilv_ui_get_uri(ui));
 
-        util::debug(plugin_uri + " ui uri: "s + ui_uri);
+        util::debug(plugin_uri + " ui uri: " + ui_uri);
 
         const LilvNode* binary_node = lilv_ui_get_binary_uri(ui);
         const LilvNode* bundle_node = lilv_ui_get_bundle_uri(ui);
