@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,13 @@
  */
 
 #include "maximizer_preset.hpp"
+#include <gio/gio.h>
+#include <nlohmann/json_fwd.hpp>
+#include "plugin_preset_base.hpp"
+#include "preset_type.hpp"
+#include "tags_plugin_name.hpp"
+#include "tags_schema.hpp"
+#include "util.hpp"
 
 MaximizerPreset::MaximizerPreset(PresetType preset_type, const int& index)
     : PluginPresetBase(tags::schema::maximizer::id,
