@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,21 @@
  */
 
 #include "multiband_gate.hpp"
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <memory>
+#include <span>
+#include <string>
+#include <utility>
+#include "lv2_wrapper.hpp"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
+#include "plugin_base.hpp"
+#include "tags_plugin_name.hpp"
+#include "util.hpp"
 
 MultibandGate::MultibandGate(const std::string& tag,
                              const std::string& schema,
@@ -119,7 +134,7 @@ void MultibandGate::process(std::span<float>& left_in,
 
     util::debug(log_tag + name + " latency: " + util::to_string(latency_value, "") + " s");
 
-    util::idle_add([=, this]() {
+    util::idle_add([this]() {
       if (!post_messages || latency.empty()) {
         return;
       }
