@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,58 @@
  */
 
 #include "pipe_manager.hpp"
+#include <glib.h>
+#include <pipewire/client.h>
+#include <pipewire/context.h>
+#include <pipewire/core.h>
+#include <pipewire/device.h>
+#include <pipewire/extensions/metadata.h>
+#include <pipewire/keys.h>
+#include <pipewire/link.h>
+#include <pipewire/module.h>
+#include <pipewire/node.h>
+#include <pipewire/pipewire.h>
+#include <pipewire/port.h>
+#include <pipewire/properties.h>
+#include <pipewire/proxy.h>
+#include <pipewire/thread-loop.h>
+#include <pipewire/version.h>
+#include <spa/monitor/device.h>
+#include <spa/param/audio/raw-types.h>
+#include <spa/param/audio/raw.h>
+#include <spa/param/format.h>
+#include <spa/param/param.h>
+#include <spa/param/props.h>
+#include <spa/param/route.h>
+#include <spa/pod/builder.h>
+#include <spa/pod/iter.h>
+#include <spa/pod/parser.h>
+#include <spa/pod/pod.h>
+#include <spa/pod/vararg.h>
+#include <spa/utils/defs.h>
+#include <spa/utils/dict.h>
+#include <spa/utils/hook.h>
+#include <spa/utils/json.h>
+#include <spa/utils/keys.h>
+#include <spa/utils/result.h>
+#include <spa/utils/type.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <array>
+#include <cerrno>
+#include <chrono>
+#include <cstdint>
+#include <cstring>
+#include <ctime>
+#include <span>
+#include <stdexcept>
+#include <string>
+#include <thread>
+#include <vector>
+#include "pipe_objects.hpp"
+#include "tags_app.hpp"
+#include "tags_pipewire.hpp"
+#include "util.hpp"
 
 namespace {
 
@@ -255,6 +307,35 @@ void on_node_info(void* object, const struct pw_node_info* info) {
     remove_node = true;
   }
 
+  bool ignore_input_stream = false;
+
+  if (nd->nd_info->media_class == tags::pipewire::media_class::input_stream && !pm->input_device.name.empty()) {
+    if (const auto* target_object = spa_dict_lookup(info->props, PW_KEY_TARGET_OBJECT)) {
+      /*
+        target.object can a name or serial number:
+        https://gitlab.freedesktop.org/pipewire/pipewire/-/blob/master/src/pipewire/keys.h#L334
+      */
+
+      uint64_t serial = SPA_ID_INVALID;
+
+      util::str_to_num(target_object, serial);
+
+      if (target_object != pm->input_device.name) {
+        ignore_input_stream = true;
+      } else if (serial != SPA_ID_INVALID && serial != pm->input_device.serial) {
+        ignore_input_stream = true;
+      }
+
+      if (ignore_input_stream) {
+        util::debug("The input stream " + nd->nd_info->name +
+                    " does not have as target the same mic used as EE input: " + pm->input_device.name +
+                    "\n The user wants it to record from device " + target_object + ". We will ignore this stream.");
+
+        remove_node = true;
+      }
+    }
+  }
+
   if (remove_node) {
     nd->nd_info->proxy = nullptr;
 
@@ -337,6 +418,32 @@ void on_node_info(void* object, const struct pw_node_info* info) {
     }
   }
 
+  // spa_dict_get_string(props, PW_KEY_APP_PROCESS_BINARY, app_process_binary);
+
+  if (const auto* app_name = spa_dict_lookup(info->props, PW_KEY_APP_NAME)) {
+    if (app_name != nd->nd_info->app_name) {
+      nd->nd_info->app_name = app_name;
+
+      app_info_ui_changed = true;
+    }
+  }
+
+  if (const auto* app_process_id = spa_dict_lookup(info->props, PW_KEY_APP_PROCESS_ID)) {
+    if (app_process_id != nd->nd_info->app_process_id) {
+      nd->nd_info->app_process_id = app_process_id;
+
+      app_info_ui_changed = true;
+    }
+  }
+
+  if (const auto* app_process_binary = spa_dict_lookup(info->props, PW_KEY_APP_PROCESS_BINARY)) {
+    if (app_process_binary != nd->nd_info->app_process_binary) {
+      nd->nd_info->app_process_binary = app_process_binary;
+
+      app_info_ui_changed = true;
+    }
+  }
+
   if (const auto* app_icon_name = spa_dict_lookup(info->props, PW_KEY_APP_ICON_NAME)) {
     if (app_icon_name != nd->nd_info->app_icon_name) {
       nd->nd_info->app_icon_name = app_icon_name;
@@ -1061,14 +1168,11 @@ void on_registry_global(void* data,
 
     std::string node_name;
 
-    if (!spa_dict_get_string(props, PW_KEY_NODE_NAME, node_name)) {
-      return;
-    }
+    spa_dict_get_string(props, PW_KEY_NODE_NAME, node_name);
 
     // At least for now I do not think there is a point in showing the spectrum adn the output level filters in menus
 
-    if (node_name.empty() || util::str_contains(node_name, "output_level") ||
-        util::str_contains(node_name, "spectrum")) {
+    if (util::str_contains(node_name, "output_level") || util::str_contains(node_name, "spectrum")) {
       return;
     }
 
@@ -1206,7 +1310,8 @@ void on_registry_global(void* data,
 
       util::debug(output_node.name + " port " + util::to_string(link_info.output_port_id) + " is connected to " +
                   input_node.name + " port " + util::to_string(link_info.input_port_id));
-    } catch (...) {
+    } catch (std::out_of_range& e) {
+      util::debug(e.what());
     }
 
     return;
@@ -1486,6 +1591,7 @@ PipeManager::PipeManager() : header_version(pw_get_headers_version()), library_v
   pw_properties_set(props_sink, PW_KEY_MEDIA_CLASS, tags::pipewire::media_class::sink);
   pw_properties_set(props_sink, "audio.position", "FL,FR");
   pw_properties_set(props_sink, "monitor.channel-volumes", "false");
+  pw_properties_set(props_sink, "monitor.passthrough", "true");
   pw_properties_set(props_sink, "priority.session", "0");
 
   proxy_stream_output_sink = static_cast<pw_proxy*>(
@@ -1505,6 +1611,7 @@ PipeManager::PipeManager() : header_version(pw_get_headers_version()), library_v
   pw_properties_set(props_source, PW_KEY_MEDIA_CLASS, tags::pipewire::media_class::virtual_source);
   pw_properties_set(props_source, "audio.position", "FL,FR");
   pw_properties_set(props_source, "monitor.channel-volumes", "false");
+  pw_properties_set(props_source, "monitor.passthrough", "true");
   pw_properties_set(props_source, "priority.session", "0");
 
   proxy_stream_input_source = static_cast<pw_proxy*>(
@@ -1578,7 +1685,7 @@ auto PipeManager::node_map_at_id(const uint& id) -> NodeInfo& {
     }
   }
 
-  throw std::out_of_range("");
+  throw std::out_of_range("No node with id " + util::to_string(id) + " in our node_map");
 }
 
 auto PipeManager::stream_is_connected(const uint& id, const std::string& media_class) -> bool {
