@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,35 @@
  */
 
 #include "pipe_manager_box.hpp"
+#include <fmt/format.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkdropdown.h>
+#include <gtk/gtkexpression.h>
+#include <gtk/gtknoselection.h>
+#include <gtk/gtkshortcut.h>
+#include <gtk/gtksingleselection.h>
+#include <sigc++/connection.h>
+#include <memory>
+#include <nlohmann/json_fwd.hpp>
+#include <string>
+#include <vector>
+#include "application.hpp"
+#include "client_info_holder.hpp"
+#include "module_info_holder.hpp"
+#include "node_info_holder.hpp"
+#include "pipe_objects.hpp"
+#include "preset_type.hpp"
+#include "presets_autoloading_holder.hpp"
+#include "tags_pipewire.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "test_signals.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::pipe_manager_box {
 
@@ -462,6 +491,10 @@ void setup(PipeManagerBox* self, app::Application* application) {
 
   g_signal_connect(self->dropdown_input_devices, "notify::selected-item",
                    G_CALLBACK(+[](GtkDropDown* dropdown, GParamSpec* pspec, PipeManagerBox* self) {
+                     if (gtk_switch_get_state(self->use_default_input) != 0) {
+                       return;
+                     }
+
                      if (auto selected_item = gtk_drop_down_get_selected_item(dropdown); selected_item != nullptr) {
                        auto* holder = static_cast<ui::holders::NodeInfoHolder*>(selected_item);
 
@@ -472,6 +505,10 @@ void setup(PipeManagerBox* self, app::Application* application) {
 
   g_signal_connect(self->dropdown_output_devices, "notify::selected-item",
                    G_CALLBACK(+[](GtkDropDown* dropdown, GParamSpec* pspec, PipeManagerBox* self) {
+                     if (gtk_switch_get_state(self->use_default_output) != 0) {
+                       return;
+                     }
+
                      if (auto selected_item = gtk_drop_down_get_selected_item(dropdown); selected_item != nullptr) {
                        auto* holder = static_cast<ui::holders::NodeInfoHolder*>(selected_item);
 
@@ -665,7 +702,7 @@ void setup(PipeManagerBox* self, app::Application* application) {
   self->data->connections.push_back(
       application->presets_manager->user_output_preset_created.connect([=](const std::string& preset_name) {
         if (preset_name.empty()) {
-          util::warning("can't retrieve information about the preset file"s);
+          util::warning("can't retrieve information about the preset file");
 
           return;
         }
@@ -682,7 +719,7 @@ void setup(PipeManagerBox* self, app::Application* application) {
   self->data->connections.push_back(
       application->presets_manager->user_output_preset_removed.connect([=](const std::string& preset_name) {
         if (preset_name.empty()) {
-          util::warning("can't retrieve information about the preset file"s);
+          util::warning("can't retrieve information about the preset file");
 
           return;
         }
@@ -699,7 +736,7 @@ void setup(PipeManagerBox* self, app::Application* application) {
   self->data->connections.push_back(
       application->presets_manager->user_input_preset_created.connect([=](const std::string& preset_name) {
         if (preset_name.empty()) {
-          util::warning("can't retrieve information about the preset file"s);
+          util::warning("can't retrieve information about the preset file");
 
           return;
         }
@@ -716,7 +753,7 @@ void setup(PipeManagerBox* self, app::Application* application) {
   self->data->connections.push_back(
       application->presets_manager->user_input_preset_removed.connect([=](const std::string& preset_name) {
         if (preset_name.empty()) {
-          util::warning("can't retrieve information about the preset file"s);
+          util::warning("can't retrieve information about the preset file");
 
           return;
         }
@@ -799,7 +836,7 @@ void dispose(GObject* object) {
   g_object_unref(self->sie_settings);
   g_object_unref(self->soe_settings);
 
-  util::debug("disposed"s);
+  util::debug("disposed");
 
   G_OBJECT_CLASS(pipe_manager_box_parent_class)->dispose(object);
 }
@@ -809,7 +846,7 @@ void finalize(GObject* object) {
 
   delete self->data;
 
-  util::debug("finalized"s);
+  util::debug("finalized");
 
   G_OBJECT_CLASS(pipe_manager_box_parent_class)->finalize(object);
 }
