@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,89 @@
  */
 
 #include "plugins_box.hpp"
+#include <STTypes.h>
+#include <adwaita.h>
+#include <gdk/gdk.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <glibconfig.h>
+#include <gobject/gobject.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkdroptarget.h>
+#include <gtk/gtkshortcut.h>
+#include <gtk/gtkwidgetpaintable.h>
+#include <sigc++/connection.h>
+#include <algorithm>
+#include <map>
+#include <ranges>
+#include <string>
+#include <vector>
+#include "application.hpp"
+#include "autogain.hpp"
+#include "autogain_ui.hpp"
+#include "bass_enhancer.hpp"
+#include "bass_enhancer_ui.hpp"
+#include "bass_loudness.hpp"
+#include "bass_loudness_ui.hpp"
+#include "compressor.hpp"
+#include "compressor_ui.hpp"
+#include "convolver.hpp"
+#include "convolver_ui.hpp"
+#include "crossfeed.hpp"
+#include "crossfeed_ui.hpp"
+#include "crystalizer.hpp"
+#include "crystalizer_ui.hpp"
+#include "deepfilternet.hpp"
+#include "deepfilternet_ui.hpp"
+#include "deesser.hpp"
+#include "deesser_ui.hpp"
+#include "delay.hpp"
+#include "delay_ui.hpp"
+#include "echo_canceller.hpp"
+#include "echo_canceller_ui.hpp"
+#include "effects_base.hpp"
+#include "equalizer.hpp"
+#include "equalizer_ui.hpp"
+#include "exciter.hpp"
+#include "exciter_ui.hpp"
+#include "expander.hpp"
+#include "expander_ui.hpp"
+#include "filter.hpp"
+#include "filter_ui.hpp"
+#include "gate.hpp"
+#include "gate_ui.hpp"
+#include "level_meter.hpp"
+#include "level_meter_ui.hpp"
+#include "limiter.hpp"
+#include "limiter_ui.hpp"
+#include "loudness.hpp"
+#include "loudness_ui.hpp"
+#include "maximizer.hpp"
+#include "maximizer_ui.hpp"
+#include "multiband_compressor.hpp"
+#include "multiband_compressor_ui.hpp"
+#include "multiband_gate.hpp"
+#include "multiband_gate_ui.hpp"
+#include "pipeline_type.hpp"
+#include "pitch.hpp"
+#include "pitch_ui.hpp"
+#include "plugins_menu.hpp"
+#include "reverb.hpp"
+#include "reverb_ui.hpp"
+#include "rnnoise.hpp"
+#include "rnnoise_ui.hpp"
+#include "speex.hpp"
+#include "speex_ui.hpp"
+#include "stereo_tools.hpp"
+#include "stereo_tools_ui.hpp"
+#include "tags_app.hpp"
+#include "tags_plugin_name.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::plugins_box {
 
@@ -631,7 +714,7 @@ void setup_listview(PluginsBox* self) {
 
         auto page = GTK_STACK_PAGE(child_item);
         auto page_name = gtk_stack_page_get_name(page);
-        auto base_name = tags::plugin_name::get_base_name(page_name);
+        const auto base_name = tags::plugin_name::get_base_name(page_name);
 
         g_object_set_data(G_OBJECT(top_box), "page-name", const_cast<char*>(page_name));
         g_object_set_data(G_OBJECT(remove), "page-name", const_cast<char*>(page_name));
@@ -738,6 +821,22 @@ void unroot(GtkWidget* widget) {
 void dispose(GObject* object) {
   auto* self = EE_PLUGINS_BOX(object);
 
+  // Setting post_messages = false for all plugins now that the window is not visible.
+
+  EffectsBase* effects_base = nullptr;
+
+  if (self->data->pipeline_type == PipelineType::input) {
+    effects_base = self->data->application->sie;
+  } else if (self->data->pipeline_type == PipelineType::output) {
+    effects_base = self->data->application->soe;
+  }
+
+  for (auto& plugin : effects_base->get_plugins_map() | std::views::values) {
+    plugin->set_post_messages(false);
+  }
+
+  // Removing gsettings connections
+
   for (auto& c : self->data->connections) {
     c.disconnect();
   }
