@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,24 @@
  */
 
 #include "presets_menu.hpp"
+#include <STTypes.h>
+#include <adwaita.h>
+#include <gio/gio.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <glibconfig.h>
+#include <gobject/gobject.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkshortcut.h>
+#include <sigc++/connection.h>
+#include <string>
+#include <vector>
+#include "application.hpp"
+#include "config.h"
+#include "preset_type.hpp"
+#include "tags_app.hpp"
+#include "tags_resources.hpp"
+#include "util.hpp"
 
 namespace ui::presets_menu {
 
@@ -37,8 +55,6 @@ struct Data {
 struct _PresetsMenu {
   GtkPopover parent_instance;
 
-  AdwViewStack* stack;
-
   GtkScrolledWindow* scrolled_window;
 
   GtkListView* listview;
@@ -286,6 +302,8 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
 
                     break;
                   }
+                  default:
+                    break;
                 }
               }
 
