@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,25 @@
  */
 
 #include "rnnoise.hpp"
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#ifdef ENABLE_RNNOISE
+#include <rnnoise.h>
+#endif
+#include <sys/types.h>
+#include <algorithm>
+#include <cmath>
+#include <cstdio>
+#include <memory>
+#include <mutex>
+#include <span>
+#include <string>
+#include "pipe_manager.hpp"
+#include "plugin_base.hpp"
+#include "resampler.hpp"
+#include "tags_plugin_name.hpp"
+#include "util.hpp"
 
 RNNoise::RNNoise(const std::string& tag,
                  const std::string& schema,
@@ -255,7 +274,7 @@ void RNNoise::process(std::span<float>& left_in,
 
     util::debug(log_tag + name + " latency: " + util::to_string(latency_value, "") + " s");
 
-    util::idle_add([=, this]() {
+    util::idle_add([this]() {
       if (!post_messages || latency.empty()) {
         return;
       }
