@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,28 @@
  */
 
 #include "stream_output_effects.hpp"
+#include <STTypes.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <pipewire/link.h>
+#include <sigc++/functors/mem_fun.h>
+#include <spa/utils/defs.h>
+#include <algorithm>
+#include <chrono>
+#include <cstdlib>
+#include <ranges>
+#include <set>
+#include <string>
+#include <thread>
+#include <vector>
+#include "effects_base.hpp"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
+#include "tags_pipewire.hpp"
+#include "tags_plugin_name.hpp"
+#include "tags_schema.hpp"
+#include "util.hpp"
 
 StreamOutputEffects::StreamOutputEffects(PipeManager* pipe_manager)
     : EffectsBase("soe: ", tags::schema::id_output, pipe_manager) {
@@ -35,7 +57,7 @@ StreamOutputEffects::StreamOutputEffects(PipeManager* pipe_manager)
     }
   }
 
-  connections.push_back(pm->sink_added.connect([=, this](const NodeInfo node) {
+  connections.push_back(pm->sink_added.connect([this](const NodeInfo node) {
     if (node.name == util::gsettings_get_string(settings, "output-device")) {
       pm->output_device = node;
 
@@ -49,7 +71,7 @@ StreamOutputEffects::StreamOutputEffects(PipeManager* pipe_manager)
     }
   }));
 
-  connections.push_back(pm->sink_removed.connect([=, this](const NodeInfo node) {
+  connections.push_back(pm->sink_removed.connect([this](const NodeInfo node) {
     if (g_settings_get_boolean(settings, "use-default-output-device") == 0) {
       if (node.name == util::gsettings_get_string(settings, "output-device")) {
         pm->output_device.id = SPA_ID_INVALID;
@@ -150,21 +172,31 @@ void StreamOutputEffects::on_link_changed(const LinkInfo link_info) {
       util::debug("At least one app linked to our device wants to play. Linking our filters.");
 
       connect_filters();
-    }
+    };
   } else {
-    int inactivity_timeout = g_settings_get_int(global_settings, "inactivity-timeout");
+    // no apps want to play, check if the inactivity timer is enabled
+    if (g_settings_get_boolean(global_settings, "inactivity-timer-enable")) {
+      // if the timer is enabled, wait for the timeout, then unlink plugin pipeline
+      int inactivity_timeout = g_settings_get_int(global_settings, "inactivity-timeout");
+      g_timeout_add_seconds(inactivity_timeout, GSourceFunc(+[](StreamOutputEffects* self) {
+                              if (!self->apps_want_to_play() && !self->list_proxies.empty()) {
+                                util::debug("No app linked to our device wants to play. Unlinking our filters.");
 
-    g_timeout_add_seconds(inactivity_timeout, GSourceFunc(+[](StreamOutputEffects* self) {
-                            if (!self->apps_want_to_play() && !self->list_proxies.empty()) {
-                              util::debug("No app linked to our device wants to play. Unlinking our filters.");
+                                self->disconnect_filters();
+                              }
 
-                              self->disconnect_filters();
-                            }
+                              return G_SOURCE_REMOVE;
+                            }),
+                            this);
 
-                            return G_SOURCE_REMOVE;
-                          }),
-                          this);
-  }
+    } else {
+      // otherwise, do nothing
+      if (!list_proxies.empty()) {
+        util::debug(
+            "No app linked to our device wants to play, but the inactivity timer is disabled. Leaving filters linked.");
+      };
+    };
+  };
 }
 
 void StreamOutputEffects::connect_filters(const bool& bypass) {
