@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,29 @@
  */
 
 #include "util.hpp"
+#include <gdk/gdk.h>
+#include <gio/gio.h>
+#include <gio/gsettingsschema.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glib/gvariant.h>
+#include <glib/gvarianttype.h>
+#include <glibconfig.h>
+#include <sys/types.h>
+#include <algorithm>
+#include <array>
+#include <cmath>
+#include <cstring>
+#include <filesystem>
+#include <functional>
+#include <iostream>
+#include <ostream>
+#include <regex>
+#include <sstream>
+#include <string>
+#include <thread>
+#include <utility>
+#include <vector>
 
 namespace util {
 
@@ -52,7 +75,7 @@ void info(const std::string& s, source_location location) {
 }
 
 void print_thread_id() {
-  std::cout << "thread id: " << std::this_thread::get_id() << std::endl;
+  std::cout << "thread id: " << std::this_thread::get_id() << '\n';
 }
 
 auto normalize(const double& x, const double& max, const double& min) -> double {
@@ -278,14 +301,15 @@ void remove_blocklist_entry(GSettings* settings, const std::string& name) {
   util::debug("an entry has been removed from the blocklist");
 }
 
-void idle_add(std::function<void()> cb) {
+void idle_add(std::function<void()> cb, std::function<void()> cleanup_cb) {
   struct Data {
-    std::function<void()> cb;
+    std::function<void()> cb, cleanup_cp;
   };
 
   auto* d = new Data();
 
   d->cb = std::move(cb);
+  d->cleanup_cp = std::move(cleanup_cb);
 
   g_idle_add((GSourceFunc) +
                  [](Data* d) {
@@ -299,6 +323,8 @@ void idle_add(std::function<void()> cb) {
 
                    d->cb();
 
+                   d->cleanup_cp();
+
                    delete d;
 
                    return G_SOURCE_REMOVE;
